@@ -16,5 +16,8 @@ class CerbosContainer(DockerContainer):
     def http_host(self, protocol: str = "http") -> str:
         return f"{protocol}://{self.get_container_host_ip()}:{self.get_exposed_port(self.HTTP_PORT)}"
 
+    def grpc_host(self) -> str:
+        return f"{self.get_container_host_ip()}:{self.get_exposed_port(self.GRPC_PORT)}"
+
     def wait_until_ready(self, timeout_secs: float = 30):
         wait_for_logs(self, r"Starting HTTP server at", timeout=timeout_secs)
